pub struct FrozenBuffer {
pub inner: Bytes,
}Expand description
An immutable buffer for reading bytes data.
The FrozenBuffer struct provides a read-only interface to byte data. Once created,
the buffer’s content cannot be modified, but it supports various reading operations
including line-by-line reading and copying data to external buffers. It implements
Python’s buffer protocol for zero-copy access from Python code.
Examples
from monarch._rust_bindings.monarch_hyperactor.buffers import Buffer
# Create and populate a buffer
buffer = Buffer()
buffer.write(b"Hello\nWorld\n")
# Freeze it for reading
frozen = buffer.freeze()
# Read all content
content = frozen.read()
print(content) # b"Hello\nWorld\n"
# Read line by line (create a new frozen buffer)
buffer.write(b"Line 1\nLine 2\n")
frozen = buffer.freeze()
line1 = frozen.readline()
line2 = frozen.readline()Fields
inner: BytesTrait Implementations
Sourceimpl Clone for FrozenBuffer
impl Clone for FrozenBuffer
Sourcefn clone(&self) -> FrozenBuffer
fn clone(&self) -> FrozenBuffer
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for FrozenBuffer
impl Default for FrozenBuffer
Sourcefn default() -> FrozenBuffer
fn default() -> FrozenBuffer
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for FrozenBuffer
impl<'de> Deserialize<'de> for FrozenBuffer
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&'static [u8]> for FrozenBuffer
impl From<&'static [u8]> for FrozenBuffer
Sourceimpl From<FrozenBuffer> for Part
impl From<FrozenBuffer> for Part
Sourcefn from(buf: FrozenBuffer) -> Self
fn from(buf: FrozenBuffer) -> Self
Converts to this type from the input type.
Sourceimpl<'py> IntoPyObject<'py> for FrozenBuffer
impl<'py> IntoPyObject<'py> for FrozenBuffer
Sourcetype Target = FrozenBuffer
type Target = FrozenBuffer
The Python output type
Sourcetype Output = Bound<'py, <FrozenBuffer as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <FrozenBuffer as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl Named for FrozenBuffer
impl Named for FrozenBuffer
Sourcefn typename() -> &'static str
fn typename() -> &'static str
The globally unique type name for the type.
This should typically be the fully qualified Rust name of the type.
Sourcefn typehash() -> u64
fn typehash() -> u64
A globally unique hash for this type.
TODO: actually enforce perfect hashing
Sourcefn typeid() -> TypeId
fn typeid() -> TypeId
The TypeId for this type. TypeIds are unique only within a binary,
and should not be used for global identification.
Sourcefn port() -> u64
fn port() -> u64
The globally unique port for this type. Typed ports are in the range
of 1<<63..1<<64-1.
Sourceimpl PartialEq for FrozenBuffer
impl PartialEq for FrozenBuffer
Sourceimpl PyClass for FrozenBuffer
impl PyClass for FrozenBuffer
Sourceimpl PyClassBaseType for FrozenBuffer
impl PyClassBaseType for FrozenBuffer
type LayoutAsBase = PyClassObject<FrozenBuffer>
type BaseNativeType = <FrozenBuffer as PyClassImpl>::BaseNativeType
type Initializer = PyClassInitializer<FrozenBuffer>
type PyClassMutability = <FrozenBuffer as PyClassImpl>::PyClassMutability
Sourceimpl PyClassImpl for FrozenBuffer
impl PyClassImpl for FrozenBuffer
Sourceconst IS_BASETYPE: bool = true
const IS_BASETYPE: bool = true
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = /// An immutable buffer for reading bytes data.
///
/// The `FrozenBuffer` struct provides a read-only interface to byte data. Once created,
/// the buffer's content cannot be modified, but it supports various reading operations
/// including line-by-line reading and copying data to external buffers. It implements
/// Python's buffer protocol for zero-copy access from Python code.
///
/// # Examples
///
/// ```python
/// from monarch._rust_bindings.monarch_hyperactor.buffers import Buffer
///
/// # Create and populate a buffer
/// buffer = Buffer()
/// buffer.write(b"Hello\nWorld\n")
///
/// # Freeze it for reading
/// frozen = buffer.freeze()
///
/// # Read all content
/// content = frozen.read()
/// print(content) # b"Hello\nWorld\n"
///
/// # Read line by line (create a new frozen buffer)
/// buffer.write(b"Line 1\nLine 2\n")
/// frozen = buffer.freeze()
/// line1 = frozen.readline()
/// line2 = frozen.readline()
/// ```
const RAW_DOC: &'static CStr = /// An immutable buffer for reading bytes data. /// /// The `FrozenBuffer` struct provides a read-only interface to byte data. Once created, /// the buffer's content cannot be modified, but it supports various reading operations /// including line-by-line reading and copying data to external buffers. It implements /// Python's buffer protocol for zero-copy access from Python code. /// /// # Examples /// /// ```python /// from monarch._rust_bindings.monarch_hyperactor.buffers import Buffer /// /// # Create and populate a buffer /// buffer = Buffer() /// buffer.write(b"Hello\nWorld\n") /// /// # Freeze it for reading /// frozen = buffer.freeze() /// /// # Read all content /// content = frozen.read() /// print(content) # b"Hello\nWorld\n" /// /// # Read line by line (create a new frozen buffer) /// buffer.write(b"Line 1\nLine 2\n") /// frozen = buffer.freeze() /// line1 = frozen.readline() /// line2 = frozen.readline() /// ```
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype ThreadChecker = SendablePyClass<FrozenBuffer>
type ThreadChecker = SendablePyClass<FrozenBuffer>
This handles following two situations: Read more
type Inventory = Pyo3MethodsInventoryForFrozenBuffer
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
fn dict_offset() -> Option<isize>
fn weaklist_offset() -> Option<isize>
Sourceimpl<'a, 'holder, 'py> PyFunctionArgument<'a, 'holder, 'py, false> for &'holder FrozenBuffer
impl<'a, 'holder, 'py> PyFunctionArgument<'a, 'holder, 'py, false> for &'holder FrozenBuffer
Sourceimpl<'a, 'holder, 'py> PyFunctionArgument<'a, 'holder, 'py, false> for &'holder mut FrozenBuffer
impl<'a, 'holder, 'py> PyFunctionArgument<'a, 'holder, 'py, false> for &'holder mut FrozenBuffer
Sourceimpl PyTypeInfo for FrozenBuffer
impl PyTypeInfo for FrozenBuffer
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type or a subclass of this type.fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type.Sourceimpl Serialize for FrozenBuffer
impl Serialize for FrozenBuffer
impl DerefToPyAny for FrozenBuffer
impl StructuralPartialEq for FrozenBuffer